tinyMCE.addI18n('fr.advanced',{
style_select:"Styles",
font_size:"Taille police",
fontdefault:"Police",
block:"Format",
paragraph:"Paragraphe",
div:"Div",
address:"Adresse",
pre:"Pr\u00E9format\u00E9",
h1:"Titre 1",
h2:"Titre 2",
h3:"Titre 3",
h4:"Titre 4",
h5:"Titre 5",
h6:"Titre 6",
blockquote:"Bloc de citation",
code:"Code",
samp:"Exemple de code",
dt:"Terme \u00E0 d\u00E9finir",
dd:"D\u00E9finition du terme",
bold_desc:"Gras (Ctrl+B)",
italic_desc:"Italique (Ctrl+I)",
underline_desc:"Soulign\u00E9 (Ctrl+U)",
striketrough_desc:"Barr\u00E9",
justifyleft_desc:"Align\u00E9 \u00E0 gauche",
justifycenter_desc:"Centr\u00E9",
justifyright_desc:"Align\u00E9 \u00E0 droite",
justifyfull_desc:"Justifi\u00E9",
bullist_desc:"Liste \u00E0 puces",
numlist_desc:"Liste num\u00E9rot\u00E9e",
outdent_desc:"Retirer l'indentation",
indent_desc:"Indenter",
undo_desc:"Annuler (Ctrl+Z)",
redo_desc:"R\u00E9tablir (Ctrl+Y)",
link_desc:"Ins\u00E9rer / \u00E9diter le lien",
unlink_desc:"Supprimer le lien",
image_desc:"Ins\u00E9rer / \u00E9diter l'image",
cleanup_desc:"Nettoyer le code",
code_desc:"\u00C9diter le code source HTML",
sub_desc:"Indice",
sup_desc:"Exposant",
hr_desc:"Ins\u00E9rer un trait horizontal",
removeformat_desc:"Supprimer le formatage",
custom1_desc:"Votre description personnalis\u00E9e ici",
forecolor_desc:"Choisir la couleur du texte",
backcolor_desc:"Choisir la couleur de surlignage",
charmap_desc:"Ins\u00E9rer des caract\u00E8res sp\u00E9ciaux",
visualaid_desc:"Activer / d\u00E9sactiver les guides et les \u00E9l\u00E9ments invisibles",
anchor_desc:"Ins\u00E9rer / \u00E9diter une ancre",
cut_desc:"Couper",
copy_desc:"Copier",
paste_desc:"Coller",
image_props_desc:"Propri\u00E9t\u00E9s de l'image",
newdocument_desc:"Nouveau document",
help_desc:"Aide",
blockquote_desc:"Citation",
clipboard_msg:"Les fonctions Copier/Couper/Coller ne sont pas valables sur Mozilla et Firefox.\nSouhaitez-vous avoir plus d'informations sur ce sujet ?",
path:"Chemin",
newdocument:"\u00CAtes-vous s\u00FBr de vouloir effacer l'int\u00E9gralit\u00E9 du document ?",
toolbar_focus:"Atteindre les boutons de l'\u00E9diteur - Alt+Q, Aller \u00E0 l'\u00E9diteur - Alt-Z, Aller au chemin de l'\u00E9l\u00E9ment - Alt-X",
more_colors:"Plus de couleurs"
});
